@@ -17,29 +17,29 @@ using namespace std;
 template<typename LHS, typename RHS, int operation>
 struct BinExpr
 {
-    template<typename Type>
+    template<typename Type>                                     // -> 69
     struct BasicType;
 
-    template<typename LH, typename RH, int oper>
+    template<typename LH, typename RH, int oper>                // -> 76
     struct BasicType<BinExpr<LH, RH, oper>>;
 
-    using ObjType = typename BasicType<RHS>::ObjType;
-    using value_type = typename ObjType::value_type;
+    using ObjType = typename BasicType<RHS>::ObjType;   // LHS, RHS must
+    using value_type = typename ObjType::value_type;    // define a value_type
 
 
     LHS const &d_lhs;
     RHS const &d_rhs;
 
-    BinExpr(LHS const &lhs, RHS const &rhs)
-    :
+    BinExpr(LHS const &lhs, RHS const &rhs)             // std constructor
+    :                                                   // sets the refs
         d_lhs(lhs),
         d_rhs(rhs)
     {}
 
-    size_t size() const
-    {
-        return d_lhs.size();
-    }
+    size_t size() const                             // LHS, RHS must define
+    {                                               // size: the size of the
+        return d_lhs.size();                        // orig. LHS type
+    }                                               // (RHS size is also OK)
 
     template <typename LH, typename RH, int oper>
     struct Operation;
@@ -66,14 +66,14 @@ struct BinExpr
     }
 };
 
-template<typename LHS, typename RHS, int operation>
+template<typename LHS, typename RHS, int operation>                     // 69
 template<typename Type>
 struct BinExpr<LHS, RHS, operation>::BasicType
 {
     using ObjType = Type;
 };
 
-template<typename LHS, typename RHS, int operation>
+template<typename LHS, typename RHS, int operation>                     // 76
 template<typename LH, typename RH, int oper>
 struct BinExpr<LHS, RHS, operation>::BasicType<BinExpr<LH, RH, oper>>
 {
@@ -168,5 +168,7 @@ int main()
                                     // the conversion operator is called.
 //    static_cast<VI>(a + b + c + d);
 
-    cout << "# index computations: " << VI::s_count << '\n';
+// 2nd cout avoids the 'not used' compiler warning
+//    cout << "# index computations: " << VI::s_count << '\n';
+    cout << "# index computations: " << e.s_count << '\n';
 }
