@@ -11,13 +11,13 @@ struct BinExpr;
 template<typename RHS>
 struct BasicType
 {
-    typedef RHS ObjType;
+    using ObjType = RHS;
 };
 
 template<typename LHS, typename RHS, template<typename> class Operation>
 struct BasicType<BinExpr<LHS, RHS, Operation>>
 {
-    typedef typename BinExpr<LHS, RHS, Operation>::ObjType ObjType;
+    using ObjType = typename BinExpr<LHS, RHS, Operation>::ObjType;
 };
 
 size_t g_binExpr;
@@ -27,8 +27,8 @@ struct BinExpr
 {
     string d_name;
 
-    typedef typename BasicType<RHS>::ObjType ObjType;
-    typedef typename ObjType::value_type value_type;
+    using ObjType = typename BasicType<RHS>::ObjType;
+    using value_type = typename ObjType::value_type;
 
     LHS const &d_lhs;
     RHS const &d_rhs;
