@@ -8,10 +8,10 @@ TableType::TableType(TableSupport &tableSupport, size_t nColumns,
     d_maxWidth(0),
     d_nRows(0),
     d_nColumns(nColumns),
-    d_widthType(ColumnWidth),
+    d_widthType(COLUMNWIDTH),
     d_colWidth(nColumns),
     d_widthFun(&TableType::columnWidth),
-    d_indexFun(direction == Horizontal ?
+    d_indexFun(direction == HORIZONTAL ?
                     &TableType::hIndex
                 :
                     &TableType::vIndex)
