@@ -36,13 +36,13 @@
                 *current;
     };
 
-        typedef reverse_iter<Type> reverse_iterator;
+    using reverse_iterator = reverse_iter<Type>;
 
-            reverse_iterator rbegin()
-            {
-                return (reverse_iterator(finish));
-            }
-            reverse_iterator rend()
-            {
-                return (reverse_iterator(data));
-            }
+    inline reverse_iterator rbegin()
+    {
+        return reverse_iterator(finish);
+    }
+    inline reverse_iterator rend()
+    {
+        return reverse_iterator(data);
+    }
