@@ -1,9 +1,15 @@
     #include <iterator>
 
-    class ForwardIterator:
-          public std::iterator<std::forward_iterator_tag, int>
+    struct ForwardIterator
     {
-        int d_value;
+        using iterator_category = std::forward_iterator_tag;
+        using difference_type   = std::ptrdiff_t;
+        using value_type        = int;
+        using pointer           = value_type *;
+        using reference         = value_type &;
+
+        private:
+            int d_value;
 
         public:
             ForwardIterator(int init);
