@@ -1,6 +1,7 @@
 #include "input.h"
 
-#include <algorithm>
+#include <numeric>
+using namespace std;
 
 int main()
 {
