@@ -11,5 +11,5 @@ int IFdNStreambuf::underflow()
         return EOF;
 
     setg(d_buffer, d_buffer, d_buffer + nread);
-    return *gptr();
+    return static_cast<unsigned char>(*gptr());
 }
