@@ -23,7 +23,7 @@ struct Next
 //class
 class Awaiter
 {
-    typedef std::coroutine_handle<> Handle;
+    using Handle = std::coroutine_handle<>;
 
     Handle d_handle;
 
