@@ -5,7 +5,7 @@
 
 class Awaiter
 {
-    typedef std::coroutine_handle<> Handle;
+    using Handle = std::coroutine_handle<>;
 
     Handle d_handle;
 
