@@ -12,8 +12,8 @@ class Letter
     std::coroutine_handle<State> d_handle;
 
     public:
-        typedef State promise_type;
-        typedef std::coroutine_handle<State> Handle;
+        using promise_type = State;
+        using Handle = std::coroutine_handle<State>;
 
         explicit Letter(Handle handle);
         ~Letter();
