@@ -10,12 +10,12 @@ struct Start
     struct State: public PromiseBase<Start, State>
     {};
 
-    typedef std::coroutine_handle<State> Handle;
+    using Handle = std::coroutine_handle<State>;
 
     std::coroutine_handle<State> d_handle;
 
     public:
-        typedef State promise_type;
+        using promise_type = State;
 
         explicit Start(Handle handle);
         ~Start();
