@@ -20,8 +20,6 @@
         copy(ov.begin(), ov.end(), ostream_iterator<int>(cout, " "));
         cout << '\n';
     }
-    /*
-        Displays:
-            1 1 3 5
-            1 1 3 5
-    */
+    //  Displays:
+    //      1 1 3 5
+    //      1 1 3 5
