@@ -45,7 +45,7 @@ void Strings::reserve()
     string *newMemory = static_cast<string *>(                  // 1
                             operator new(d_capacity * sizeof(string)));
     for (size_t idx = 0; idx != d_size; ++idx)                  // 2
-        new (newMemory + idx) string(d_memory[idx]);
+        new (newMemory + idx) string{ d_memory[idx] };
     destroy();                                                  // 3
     d_memory = newMemory;
 }
