@@ -9,11 +9,11 @@
             cout << store.at(idx) << '\n';
     }
 
-    Strings *process(char *argv[], int argc)
+    Strings *process(char *argv[], size_t argc)
     {
-        Strings store(argv, argc);
+        Strings store{ argv, argc };
         display(store);
-        return new Strings(argv, argc);
+        return new Strings{ argv, argc };
     }
 
     int main(int argc, char *argv[])
@@ -22,6 +22,6 @@
         delete sp;
 
         char buffer[sizeof(Strings)];
-        sp = new (buffer) Strings(argv, argc);
+        sp = new (buffer) Strings{ argv, static_cast<size_t>(argc) };
         sp->~Strings();
     }
