@@ -1,4 +1,5 @@
-import Math;
+#include "math.i"
+//import Math;
 
 Math::Math()
 :
