@@ -1,4 +1,4 @@
-import Template;
+import Adder;
 
 import <iostream>;
 import <string>;
