@@ -7,6 +7,8 @@ using namespace std;
 using namespace chrono;
 using namespace filesystem;
 
+namespace fs = filesystem;
+
 auto local_time_point(time_point<system_clock> const &tp, char const *fmt)
 {
     time_t secs = system_clock::to_time_t( tp );
@@ -16,7 +18,13 @@ auto local_time_point(time_point<system_clock> const &tp, char const *fmt)
 int main()
 {
 //    system_clock::duration ds{ 24h };
-//    __file_clock::duration df{ 1h };
+//    file_clock::duration df{ 1h };
+
+    file_clock::time_point p1 = fs::last_write_time("clock.cc");
+    file_clock::time_point p2 = fs::last_write_time("clock.cc");
+
+    cout << (p1 == p2) << '\n';
+return 0;
 
     system_clock::from_time_t(
         system_clock::to_time_t(
@@ -34,19 +42,19 @@ int main()
 
     cout << local_time_point(system_clock{}.now(), "%c") << '\n';
 
-//    __file_clock::to_time_t(__file_clock::from_time_t(12345));
+//    file_clock::to_time_t(file_clock::from_time_t(12345));
     high_resolution_clock::to_time_t(high_resolution_clock::from_time_t(12345));
 //    steady_clock::to_time_t(steady_clock::from_time_t(12345));
 
 //    unsigned uval = system_clock::period::num;
 
-//    __file_clock::period rf;
+//    file_clock::period rf;
 
 
 //    system_clock::rep vs;
-//    __file_clock::rep vf;
+//    file_clock::rep vf;
 
 //    system_clock::time_point st = system_clock{}.now();
 
-    __file_clock::time_point ft;
+    file_clock::time_point ft;
 }
