@@ -2,8 +2,8 @@
 
     class IntArray
     {
-        int     *d_data;
         size_t d_size;
+        int     *d_data;
 
          public:
             IntArray(size_t size = 1);
@@ -13,7 +13,7 @@
 
                                                 // overloaded index operators:
             int &operator[](size_t index);              // first
-            int operator[](size_t index) const;         // second
+            int const &operator[](size_t index) const;  // second
 
             void swap(IntArray &other);         // trivial
 
