@@ -1,4 +1,3 @@
-    #include <iostream>
     #include <string>
     #include <memory>
     using namespace std;
@@ -19,7 +18,10 @@
     };
     int main()
     {
-        unique_ptr<string *, Deleter> sp2{ new string *[10], Deleter{ 10 } };
+        unique_ptr<string *, Deleter> sp2{ new string *[10](),
+                                           Deleter{ 10 } };
 
-        Deleter &obj = sp2.get_deleter();
+                                        // for illustration purposes:
+                                        // retrieving the Deleter
+        [[maybe_unused]] Deleter &obj = sp2.get_deleter();
     }
