@@ -20,15 +20,8 @@ void run()
     thread(add, int(v1), int(v2)).detach();     // this is OK: own copies
 }
 
-void oops()
-{
-    int v1 = 0;
-    int v2 = 0;
-}
-
 int main()
 {
     run();
-    oops();
     this_thread::sleep_for(seconds(1));
 }
