@@ -18,7 +18,7 @@ void process(int nr)
             return;
         }
 
-        string command("/usr/bin/g++ --std=c++11 -c " + line);
+        string command("/usr/bin/g++ -c " + line);
 
         CmdFork cmdFork(command);
         cmdFork.fork();
